@@ -325,4 +325,48 @@ def avgQtySoldList(file):
         avg_qty = sales_qty.quantity.mean()
         result = result.append({'product_number': pnum, 'product_name': sales_prep['product_name'].iloc[0], 'QTY Sold by Year': avg_qty}, ignore_index=True)
     result.to_csv('avgQtySoldList.csv', index = False)
-    print("Average Quantity Sold Per Year", result, sep='\n')
\ No newline at end of file
+    print("Average Quantity Sold Per Year", result, sep='\n')
+    
+# def purchasingMetricList(salesData,eoqCost,serviceRate):
+#     sales = pd.read_csv(salesData)
+#     eoqCost = pd.read_csv(eoqCost)
+#     sales['ref'] = sales['ref'].astype('category')
+#     sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+#     sales['product_number'] = sales['product_number'].astype('category')
+#     sales['product_name'] = sales['product_name'].astype('category')
+#     sales = sales.dropna()
+#     result = pd.DataFrame(columns=['product_number', 'product_name', 'avg_qty_sold', 'setup_cost', 'holding_cost', 'leadtimeInDays', 'safety_stock', 'reorder_point', 'EOQ'])
+#     for pnum in eoqCost.product_number.unique():
+#         sales_prep = sales.loc[sales['product_number'] == pnum]
+#         sales_qty = sales_prep[['date','quantity']]
+#         sales_qty = sales_qty.set_index(["date"])
+#         sales_qty = sales_qty.resample('Y').sum()
+#         avg_qty = sales_qty.quantity.mean()
+#         mergedDF = sales_prep.merge(eoqCost, on='product_number', how='right')
+#         safety_stock = norm.ppf(serviceRate)*np.std(sales_qty.quantity)*np.sqrt(mergedDF.leadtimeInDays.mean()/30)
+#         reorder_point = safety_stock+avg_qty*mergedDF.leadtimeInDays.mean()
+#         EOQ = math.sqrt(2*avg_qty*mergedDF.setup_cost.mean()/mergedDF.holding_cost.mean())
+#         result = result.append({'product_number': pnum, 'product_name': sales_prep['product_name'].iloc[0], 'avg_qty_sold': avg_qty, 'setup_cost': mergedDF['setup_cost'].iloc[0], 'holding_cost': mergedDF['holding_cost'].iloc[0], 'leadtimeInDays': mergedDF['leadtimeInDays'].iloc[0], 'safety_stock': safety_stock, 'reorder_point': reorder_point, 'EOQ': EOQ}, ignore_index=True)
+#     result.to_csv('PurchasingMetrics.csv', index = False)
+#     print("Purchasing Metrics", result, sep='\n')
+    
+def seasonalityIndexPerProduct(file,product_number,year):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales['total_amount'] = sales['quantity']*sales['price']
+    sales = sales.loc[sales['product_number'] == product_number]
+    sales['year'] = pd.DatetimeIndex(sales['date']).year
+    sales['month'] = pd.DatetimeIndex(sales['date']).month
+    sales_amount = sales.set_index(["date"])
+    sales_amount = sales_amount.reset_index()
+    sales_amount = sales_amount[['year','month','total_amount']]
+    sales_amount_year = sales_amount.loc[sales_amount['year'] == year]
+    seationality_index_year = sales_amount_year.groupby(['month']).sum()
+    seationality_index_year['seasonality_index'] = seationality_index_year['total_amount']/seationality_index_year.total_amount.sum()
+    seationality_index_year['year'] = year
+    seationality_index_year.reset_index()
+    seationality_index_year.to_csv('SeasonalityIndexPerProduct.csv', index = False)
+    print("Seasonality Index Per Product", seationality_index_year, sep='\n')
\ No newline at end of file
